==> mdut-22.3.1.tar.gz: mdut-22.3.1/CHANGELOG.md <==
# mdut Changelog


<!--
headers:
Added      - new features
Changed    - changes in existing functionality
Deprecated - soon-to-be removed features
Removed    - now removed features
Fixed      - any bug fixes
Security   - in case of vulnerabilities
-->


## [Unreleased]


## [22.3.1]

### Changed

- CalVer from `YYYY.minor.micro` to `YY.minor.micro`


## [2022.3.2]

### Added

- [Reversioning][yanked] notice


## [2022.3.1] - [yanked]

### Fixed

- Quotes in titles are now escaped


## [2022.3.0] - [yanked]

### Added

- Missing reference style tests
- Slack style

### Changed

- Reordered styles to put default first


## [2022.2.0] - [yanked]

### Added

- Fallback from no protocol and http to https


## [2022.1.0] - [yanked]

### Added

- CI workflow for automated code quality checks
- Support for Python 3.7, 3.8, and 3.9

### Fixed

- Minor linter errors


## [2022.0.1] - [yanked]

### Added

- Initial release! 🎉


[yanked]: https://nkantar.com/blog/2022/01/reversioning-mdut/ "Reversioning mdut | Blog | Nik Kantar"


[Unreleased]: https://github.com/nkantar/mdut/compare/22.3.1...HEAD
[22.3.1]: https://github.com/nkantar/mdut/compare/2022.3.1...22.3.1
[2022.3.1]: https://github.com/nkantar/mdut/compare/2022.3.0...2022.3.1
[2022.3.0]: https://github.com/nkantar/mdut/compare/2022.2.0...2022.3.0
[2022.2.0]: https://github.com/nkantar/mdut/compare/2022.1.0...2022.2.0
[2022.1.0]: https://github.com/nkantar/mdut/compare/2022.0.1...2022.1.0
[2022.0.1]: https://github.com/nkantar/mdut/releases/tag/2022.0.1

==> mdut-22.6.0.tar.gz: mdut-22.6.0/CHANGELOG.md <==
# mdut Changelog


<!--
headers:
Added      - new features
Changed    - changes in existing functionality
Deprecated - soon-to-be removed features
Removed    - now removed features
Fixed      - any bug fixes
Security   - in case of vulnerabilities
-->


## [Unreleased]

### Fixed

- Whitespace surrounding title text


## [22.3.1]

### Changed

- CalVer from `YYYY.minor.micro` to `YY.minor.micro`


## [2022.3.1] - ~~[yanked]~~ deleted

### Fixed

- Quotes in titles are now escaped


## [2022.3.0] - ~~[yanked]~~ deleted

### Added

- Missing reference style tests
- Slack style

### Changed

- Reordered styles to put default first


## [2022.2.0] - ~~[yanked]~~ deleted

### Added

- Fallback from no protocol and http to https


## [2022.1.0] - ~~[yanked]~~ deleted

### Added

- CI workflow for automated code quality checks
- Support for Python 3.7, 3.8, and 3.9

### Fixed

- Minor linter errors


## [2022.0.1] - ~~[yanked]~~ deleted

### Added

- Initial release! 🎉


[yanked]: https://nkantar.com/blog/2022/01/reversioning-mdut/ "Reversioning mdut | Blog | Nik Kantar"


[Unreleased]: https://github.com/nkantar/mdut/compare/22.3.1...HEAD
[22.3.1]: https://github.com/nkantar/mdut/compare/2022.3.1...22.3.1
[2022.3.1]: https://github.com/nkantar/mdut/compare/2022.3.0...2022.3.1
[2022.3.0]: https://github.com/nkantar/mdut/compare/2022.2.0...2022.3.0
[2022.2.0]: https://github.com/nkantar/mdut/compare/2022.1.0...2022.2.0
[2022.1.0]: https://github.com/nkantar/mdut/compare/2022.0.1...2022.1.0
[2022.0.1]: https://github.com/nkantar/mdut/releases/tag/2022.0.1
